@@ -11,7 +11,7 @@ module Cinch
     def initialize(mask)
       @mask = mask
       @nick, @user, @host = mask.match(/(.+)!(.+)@(.+)/)[1..-1]
-      @regexp = Regexp.new("^" + Regexp.escape(mask).gsub("\\*", ".*") + "$")
+      @regexp = Regexp.new("^" + Regexp.escape(mask).gsub("\\*", ".*").gsub("\\?", ".?") + "$")
     end
 
     # @return [Boolean]
@@ -28,10 +28,10 @@ module Cinch
       @mask.hash
     end
 
-    # @param [User] user
+    # @param [Ban, Mask, User, String] target
     # @return [Boolean]
-    def match(user)
-      return user.mask =~ @regexp
+    def match(target)
+      return self.class.from(target).mask =~ @regexp
 
       # TODO support CIDR (freenode)
     end
